RaschModel is a wrapper function that creates a "StatModel" object
with certain fitting parameters passed on to RaschModel.fit for fitting
simple Rasch models.RaschModel(gradtol = 1e-6, deriv = c("sum", "diff", "numeric"))RaschModel.fit(y, weights = NULL, start = NULL, gradtol = 1e-6,
deriv = c("sum", "diff", "numeric"), ...)
as.matrix) to binary 0/1 matrix."sum"),
analytical with difference algorithm ("diff", faster but numerically unstable),
or nlm.RaschModel returns an S4 object of class "StatModel" that fits Rasch models
with the specified arguments. RaschModel.fit returns an S3 object of class
"RaschModel", i.e., a list with components as follows.nlm,nlm,nlm.RaschModel is the S4 interface for RaschModel.fit so that it
can be used in mob. The user does not have to
call this directly but can simply use the raschtree
interface.raschtree