Usage
raschtree(formula, data, na.action,
reltol = 1e-10, deriv = c("sum", "diff", "numeric"), maxit = 100L,
...)## S3 method for class 'raschtree':
predict(object, newdata = NULL,
type = c("probability", "cumprobability", "mode", "median", "mean",
"category-information", "item-information", "test-information", "node"),
personpar = 0, ...)
## S3 method for class 'raschtree':
plot(x, type = c("profile", "regions"), terminal_panel = NULL,
tp_args = list(...), tnex = 2L, drop_terminal = TRUE, ...)
Arguments
formula
A symbolic description of the model to be fit. This
should be of type y ~ x1 + x2
where y should be a binary 0/1 item response matrix
and x1 and x2 are used as partitioning variables.
data
a data frame containing the variables in the model.
na.action
a function which indicates what should happen when the data
contain missing values (NAs).
deriv
character. Which type of derivatives should be used for computing
gradient and Hessian matrix? Analytical with sum algorithm ("sum"),
analytical with difference algorithm ("diff", faster but numerically unstable),
or
...
arguments passed to the underlying functions, i.e., to
mob_control for raschtree, and to the
underlying predict and plot methods, respectively. object, x
an object of class "raschtree".
newdata
optional data frame with partitioning variables for
which predictions should be computed. By default the learning data set
is used.
type
character specifying the type of predictions or plot. For the
predict method, either just the ID of the terminal "node"
can be predicted or some property of the model at a given person parameter
(specified by pe
personpar
numeric person parameter (of length 1) at which the
predictions are evaluated.
terminal_panel, tp_args, tnex, drop_terminal